@@ -70,12 +70,22 @@ class BotStats(utils.Cog):
         embed.add_field("Creator", f"{creator!s}\n{creator_id}")
         embed.add_field("Library", f"Discord.py {discord.__version__}")
         if self.bot.shard_count != len((self.bot.shard_ids or [0])):
-            embed.add_field("Approximate Guild Count", format(int((len(self.bot.guilds) / len(self.bot.shard_ids or [0])) * self.bot.shard_count), ","))
+            embed.add_field(
+                "Approximate Guild Count",
+                f"{int((len(self.bot.guilds) / len(self.bot.shard_ids or [0])) * self.bot.shard_count):,}",
+            )
         else:
-            embed.add_field("Guild Count", format(len(self.bot.guilds), ","))
-        embed.add_field("Shard Count", format(self.bot.shard_count or 1, ","))
+            embed.add_field("Guild Count", f"{len(self.bot.guilds):,}")
+        embed.add_field("Shard Count", f"{self.bot.shard_count or 1:,}")
         embed.add_field("Average WS Latency", f"{(self.bot.latency * 1000):.2f}ms")
-        embed.add_field("Coroutines", f"{len([i for i in asyncio.Task.all_tasks() if not i.done()])} running, {len(asyncio.Task.all_tasks())} total.")
+        try:
+            all_tasks = asyncio.Task.all_tasks()
+        except AttributeError:
+            all_tasks = asyncio.all_tasks()
+        embed.add_field(
+            "Coroutines",
+            f"{len([i for i in all_tasks if not i.done()]):,} running, {len(all_tasks):,} total.",
+        )
 
         # Get topgg data
         if self.bot.config.get('bot_listing_api_keys', {}).get("topgg_token"):
@@ -87,7 +97,10 @@ class BotStats(utils.Cog):
                 except Exception:
                     data = {}
             if "points" in data and "monthlyPoints" in data:
-                embed.add_field("Bot Votes", f"[Top.gg](https://top.gg/bot/{self.bot.user.id}): {data['points']} ({data['monthlyPoints']} this month)")
+                embed.add_field(
+                    "Bot Votes",
+                    f"[Top.gg](https://top.gg/bot/{self.bot.user.id}): {data['points']:,} ({data['monthlyPoints']:,} this month)",
+                )
 
         # Get discordbotlist data
         if self.bot.config.get('bot_listing_api_keys', {}).get("discordbotlist_token"):
@@ -99,7 +112,7 @@ class BotStats(utils.Cog):
             if "upvotes" in data and "metrics" in data:
                 content = {
                     "name": "Bot Votes",
-                    "value": f"[DiscordBotList.com](https://discordbotlist.com/bots/{self.bot.user.id}): {data['metrics'].get('upvotes', 0)} ({data['upvotes']} this month)"
+                    "value": f"[DiscordBotList.com](https://discordbotlist.com/bots/{self.bot.user.id}): {data['metrics'].get('upvotes', 0):,} ({data['upvotes']:,} this month)"
                 }
                 try:
                     current_data = embed.get_field_by_key("Bot Votes")
@@ -110,7 +123,7 @@ class BotStats(utils.Cog):
             elif "upvotes" in data:
                 content = {
                     "name": "Bot Votes",
-                    "value": f"[DiscordBotList.com](https://discordbotlist.com/bots/{self.bot.user.id}): {data['upvotes']}"
+                    "value": f"[DiscordBotList.com](https://discordbotlist.com/bots/{self.bot.user.id}): {data['upvotes']:,}"
                 }
                 try:
                     current_data = embed.get_field_by_key("Bot Votes")
