@@ -1,7 +1,7 @@
-# flake8: noqa
 from .user_id import UserID
 from .channel_id import ChannelID
 from .enum_converter import EnumConverter
 from .boolean_converter import BooleanConverter
 from .colour_converter import ColourConverter
 from .filtered_user import FilteredUser, FilteredMember
+from .number_converter import NumberConverter
