@@ -4,7 +4,6 @@ import glob
 import logging
 import typing
 import copy
-from datetime import datetime as dt
 from urllib.parse import urlencode
 import string
 import platform
@@ -25,6 +24,7 @@ from .statsd import StatsdConnection
 from .analytics_log_handler import AnalyticsLogHandler
 from .upgrade_chat import UpgradeChat
 from .interactions.components import MessageComponents
+from .models import ComponentMessage, ComponentWebhookMessage
 from . import interactions
 from .. import all_packages as all_vfl_package_names
 
@@ -86,39 +86,6 @@ class RouteV8(discord.http.Route):
     BASE = 'https://discord.com/api/v8'
 
 
-_original_message = discord.Message
-_original_webhook_message = discord.WebhookMessage
-
-
-class ComponentMessage(_original_message):
-
-    __slots__ = _original_message.__slots__ + ("components",)
-
-    def __init__(self, *, state, channel, data):
-        self.components = MessageComponents.from_dict(data.get("components", list()))
-        super().__init__(state=state, channel=channel, data=data)
-
-    async def wait_for_component_interaction(self, *args, **kwargs):
-        pass
-
-    async def clear_components(self, *args, **kwargs):
-        pass
-
-    async def disable_components(self, *args, **kwargs):
-        pass
-
-    async def enable_components(self, *args, **kwargs):
-        pass
-
-    @classmethod
-    async def convert(cls, ctx, value):
-        return await commands.MessageConverter().convert(ctx, value)
-
-
-class ComponentWebhookMessage(ComponentMessage, _original_webhook_message):
-    pass
-
-
 class MinimalBot(commands.AutoShardedBot):
     """
     A minimal version of the VoxelBotUtils bot that inherits from :class:`discord.ext.commands.AutoShardedBot`
@@ -156,6 +123,9 @@ class MinimalBot(commands.AutoShardedBot):
         async def enable_components_msg_prop(message):
             return await message.edit(components=message.components.enable_components())
 
+        # def create_message_prop(state, *args, **kwargs):
+        #     return ComponentMessage(state=state, *args, **kwargs)
+
         Messageable.send = send_button_msg_prop
         discord.message.MessageFlags.ephemeral = discord.flags.flag_value(lambda _: 64)
         discord.message.MessageFlags.VALID_FLAGS.update({"ephemeral": 64})
@@ -181,6 +151,8 @@ class MinimalBot(commands.AutoShardedBot):
         # discord.Message = ComponentMessage
         # discord.WebhookMessage = ComponentWebhookMessage
 
+        # ConnectionState.create_message = create_message_prop
+
     async def get_application_id(self) -> int:
         """
         Get the bot's application client ID.
@@ -415,8 +387,8 @@ class MinimalBot(commands.AutoShardedBot):
             components: MessageComponents = None,
             ephemeral: bool = False, embeddify: bool = None,
             image_url: bool = None, embeddify_file: bool = True,
-            wait: bool = True,
-            embeds: typing.List[discord.Embed] = None):
+            wait: bool = True, embeds: typing.List[discord.Embed] = None,
+            _no_wait_response_type: int = 4):
         """
         An alternative send method so that we can add components to messages.
 
@@ -429,7 +401,10 @@ class MinimalBot(commands.AutoShardedBot):
             messageable, content=content, embed=embed, file=file, embeddify=embeddify,
             image_url=image_url, embeddify_file=embeddify_file,
         )
-        state = self._connection
+        try:
+            state = messageable._state
+        except AttributeError:
+            state = self._connection
         lock = getattr(messageable, "_send_interaction_response_lock", asyncio.Lock())
         await lock.acquire()
 
@@ -482,19 +457,19 @@ class MinimalBot(commands.AutoShardedBot):
         # Send a response if it's an interaction
         if isinstance(channel, (list, tuple)):
 
-            # Sent no responses - send an ack
+            # Sent no responses but we want a message back - send a defer
             if not messageable._sent_ack_response and wait:
-                await messageable.ack(ephemeral=ephemeral)
+                await messageable.defer(ephemeral=ephemeral)
 
             # Sent no responses but we don't want a message object back from Discord
             elif not messageable._sent_ack_response:
                 r = discord.http.Route('POST', '/interactions/{interaction_id}/{token}/callback', interaction_id=channel[0], token=channel[2])
 
-            # Sent an ack that we should edit
+            # Sent a defer that we should edit
             if wait and messageable.ACK_IS_EDITABLE and messageable._sent_ack_response and not messageable._sent_message_response:
                 r = discord.http.Route('PATCH', '/webhooks/{app_id}/{token}/messages/@original', app_id=channel[1], token=channel[2])
 
-            # Sent an ack and a response, or sent an ack with no editable original message
+            # Sent a defer and a response, or sent a defer with no editable original message
             elif wait:
                 r = discord.http.Route('POST', '/webhooks/{app_id}/{token}', app_id=channel[1], token=channel[2])
 
@@ -550,7 +525,7 @@ class MinimalBot(commands.AutoShardedBot):
                     f.close()
         else:
             if wait is False:
-                payload = {"type": 4, "data": payload.copy()}
+                payload = {"type": _no_wait_response_type, "data": payload.copy()}
             response_data = await messageable._state.http.request(r, json=payload)
 
         # Set the attributes for the interactions
@@ -572,9 +547,10 @@ class MinimalBot(commands.AutoShardedBot):
             webhook = discord.Webhook.partial(channel[1], channel[2], adapter=discord.AsyncWebhookAdapter(session=self.session))
             webhook._state = self._connection
             partial_webhook_state = discord.webhook._PartialWebhookState(webhook._adapter, webhook, parent=webhook._state)
-            ret = discord.WebhookMessage(data=response_data, state=partial_webhook_state, channel=messageable.channel)
+            ret = ComponentWebhookMessage(data=response_data, state=partial_webhook_state, channel=messageable.channel)
         else:
-            ret = state.create_message(channel=channel, data=response_data)
+            # ret = state.create_message(channel=channel, data=response_data)
+            ret = ComponentMessage(state=state, channel=channel, data=response_data)
 
         # See if we want to delete the message
         lock.release()
@@ -735,9 +711,9 @@ class Bot(MinimalBot):
 
     def __init__(
             self, config_file: str = 'config/config.toml', logger: logging.Logger = None,
-            activity:discord.Activity = discord.Game(name="Reconnecting..."),
+            activity: discord.Activity = discord.Game(name="Reconnecting..."),
             status: discord.Status = discord.Status.dnd, case_insensitive: bool = True,
-            intents:discord.Intents = None,
+            intents: discord.Intents = None,
             allowed_mentions: discord.AllowedMentions = discord.AllowedMentions(everyone=False),
             *args, **kwargs):
         """
@@ -1356,7 +1332,7 @@ class Bot(MinimalBot):
         if ctx.command is None:
             return await super().invoke(ctx)
         command_stats_name = ctx.command.qualified_name.replace(' ', '_')
-        command_stats_tags = {"command_name": command_stats_name, "slash_command": ctx.IS_INTERACTION}
+        command_stats_tags = {"command_name": command_stats_name, "slash_command": ctx.is_interaction}
         async with self.stats() as stats:
             stats.increment("discord.bot.commands", tags=command_stats_tags)
         return await super().invoke(ctx)
