@@ -43,7 +43,7 @@ class Menu(MenuDisplayable):
         self.component_display = component_display  # Used for nested menus
         self._options = list(options)
 
-    def create_cog(self, *, cog_name: str = "Bot Settings", name: str = "setup", aliases: typing.List[str] = None, **command_kwargs):
+    def create_cog(self, bot=None, *, cog_name: str = "Bot Settings", name: str = "setup", aliases: typing.List[str] = None, **command_kwargs):
         """
         Creates a cog that can be loaded into the bot in a setup method.
         """
@@ -55,6 +55,8 @@ class Menu(MenuDisplayable):
             async def setup(nested_self, ctx):
                 await self.start(ctx)
 
+        if bot:
+            return NestedCog(bot)
         return NestedCog
 
     async def get_options(self, ctx: commands.Context, force_regenerate: bool = False):
@@ -87,7 +89,7 @@ class Menu(MenuDisplayable):
                     return False
                 if payload.user.id == ctx.author.id:
                     return True
-                payload.respond(f"Only {ctx.author.mention} can interact with these buttons.", ephemeral=True)
+                ctx.bot.loop.create_task(payload.respond(f"Only {ctx.author.mention} can interact with these buttons.", ephemeral=True))
                 return False
             return button_check
 
@@ -97,7 +99,7 @@ class Menu(MenuDisplayable):
             # Wait for the user to click on a button
             try:
                 payload = await ctx.bot.wait_for("component_interaction", check=get_button_check(menu_message), timeout=60.0)
-                await payload.ack()
+                await payload.defer_update()
             except asyncio.TimeoutError:
                 break
 
