@@ -1,11 +1,11 @@
 cog_example = '''
-import voxelbotutils as utils
+import voxelbotutils as vbu
 
 
-class PingCommand(utils.Cog):
+class PingCommand(vbu.Cog):
 
-    @utils.command()
-    async def ping(self, ctx:utils.Context):
+    @vbu.command()
+    async def ping(self, ctx: vbu.Context):
         """
         A sexy lil ping command for the bot.
         """
@@ -13,7 +13,7 @@ class PingCommand(utils.Cog):
         await ctx.send("Pong!")
 
 
-def setup(bot:utils.Bot):
+def setup(bot: vbu.Bot):
     x = PingCommand(bot)
     bot.add_cog(x)
 '''
