@@ -1,7 +1,7 @@
 database_file = """
 CREATE TABLE IF NOT EXISTS guild_settings(
     guild_id BIGINT PRIMARY KEY,
-    prefix VARCHAR(30)
+    prefix TEXT
 );
 
 
@@ -13,8 +13,8 @@ CREATE TABLE IF NOT EXISTS user_settings(
 CREATE TABLE IF NOT EXISTS role_list(
     guild_id BIGINT,
     role_id BIGINT,
-    key VARCHAR(50),
-    value VARCHAR(50),
+    key TEXT,
+    value TEXT,
     PRIMARY KEY (guild_id, role_id, key)
 );
 
@@ -22,8 +22,8 @@ CREATE TABLE IF NOT EXISTS role_list(
 CREATE TABLE IF NOT EXISTS channel_list(
     guild_id BIGINT,
     channel_id BIGINT,
-    key VARCHAR(50),
-    value VARCHAR(50),
+    key TEXT,
+    value TEXT,
     PRIMARY KEY (guild_id, channel_id, key)
 );
 """
